#!/bin/csh

# Single Analysis Processing Script
# Created by: Bryan M. Williams on September 10, 2013

set date=$1
set fhr=$2

set cdate=`date +'%Y%m%d_%H%M'`
set dir=`pwd`
set timestring=$cdate

#Load and source the config file.

source $dir/config

# If indicated in the config, delete the maps and logfiles folder.

if($remove_folders == 1) then
  echo 'Recreating folders...'
  rm -r maps/
  rm -r logfiles/

  mkdir logfiles
  mkdir maps
  mkdir maps/NatureRun
  mkdir maps/3plotWinds
endif

# Create file lists.

set nrname=${NR_type}${date}'00'

echo $SIN_TYPE' '$nrname >> list.txt
echo $SIN_TYPE'.ctl '$nrname'.ctl' >> filelist.txt

# If the required directories are missing, create them.

if(! -d logfiles) then
  echo 'Logfiles directory missing! creating new one...'
  mkdir logfiles
endif

if(! -d maps) then
  echo 'Maps directory missing! Creating new one...'
  mkdir maps
endif

# Create the control and index files to be used in the script.

echo 'Crating control and index files...'
foreach line ("`cat list.txt`")
  set file1=`echo $line | cut -d " " -f1`
  set file2=`echo $line | cut -d " " -f2`

  ./grib2ctl -verf $SIN_ROOT/$file1 ./$file1.idx >> $file1.ctl
  gribmap -v -i $file1.ctl >> log_${file1}_gribmap.txt

  ./grib2ctl -verf $ROOT_NR/$file2 ./$file2.idx >> $file2.ctl
  gribmap -v -i $file2.ctl >> log_${file2}_gribmap.txt

# Create graphics.

echo 'Creating graphics for analysis time...'
foreach line ("`cat filelist.txt`")

  set file1=`echo $line | cut -d " " -f1`
  set file2=`echo $line | cut -d " " -f2`

  /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -bpcx "run FindLatLon.gs $file1 $file2" >> log_LatLon.txt

  /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -bpcx "run mplot_test.gs $file1 $date $fhr $title 1" >> log_mplot.txt

  /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -bpcx "run mplot_test_nr.gs $file2 $date $date $fhr $titlenr 1" >> log_mplot_nr.txt

  /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -bpcx "run 3plot_wind.gs $file1 $date $fhr $title 1 $level1 $level2 $level3" >> log_3plot_wind.txt

  /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -bpcx "run 3plot_wind.gs $file2 $date $fhr $titlenr 1 $level1 $level2 $level3" >> log_3plot_wind_nr.txt
end

echo 'Cleaning up...'
mv log_* logfiles/

mv 3plot_wind*.png maps/3plotWinds
mv *_nr.png maps/NatureRun/

rm list.txt
rm filelist.txt
rm *.ctl
rm *.idx

echo 'The script is finished and will now close.'
exit 0
