#!/bin/csh -x

set start=$1
set fhr=$2
set step=$3

if($step == 0) then
  set chr=$fhr
else
  set chr=0
endif

set date=`date +'%Y%m%d%H%M'`
set dir=`pwd`
set timestring=`date`

# Load and source the config file.

source $dir/triple_config

# If indicated in the config, delete the maps and logfiles folder.

# mkdir ${start}_$title

  mkdir logfiles
  mkdir maps
  mkdir maps/NatureRun
  mkdir maps/3plotWinds
  mkdir maps/3plotWinds/NatureRun
  mkdir dsets
  mkdir graphs/

# Create file lists.

echo 'Creating lists...'
while($fhr >= $chr)
  if(`echo $chr | wc -c` - 1 == 1) then
    set fname1=${ROOT_TYPE1}'00'${chr}${ROOT_END1}
    set fname2=${ROOT_TYPE2}'00'${chr}${ROOT_END2}
    set fname3=${ROOT_TYPE3}'00'${chr}${ROOT_END3}
  else if(`echo $chr | wc -c` - 1 == 2) then
    set fname1=${ROOT_TYPE1}'0'${chr}${ROOT_END1}
    set fname2=${ROOT_TYPE2}'0'${chr}${ROOT_END2}
    set fname3=${ROOT_TYPE3}'0'${chr}${ROOT_END3}
  else
    set fname1=${ROOT_TYPE1}${chr}${ROOT_END1}
    set fname2=${ROOT_TYPE2}${chr}${ROOT_END2}
    set fname3=${ROOT_TYPE3}${chr}${ROOT_END3}
  endif
  set cdate=`./timestring.sh $start $chr`
  set nrname=${NR_TYPE}${cdate}'00'
  echo $fname1' '$fname2' '$fname3' '$nrname >> list.txt
  echo $title1'_'$fname1'.ctl '$title2'_'$fname2'.ctl '$title3'_'$fname3'.ctl '$nrname'.ctl' >> filelist.txt
  if($step == 0) then
    break
  else
    @ chr=$chr + $step
  endif
end

if($step == 0) then
  set chr=$fhr
else
  set chr=0
endif

echo 'Creating control and index files...'
foreach line ("`cat list.txt`")
  set file1=`echo $line | cut -d " " -f1`
  set file2=`echo $line | cut -d " " -f2`
  set file3=`echo $line | cut -d " " -f3`
  set file4=`echo $line | cut -d " " -f4`

  if(! -e ${ROOT1}/${file1} || ! -e ${ROOT2}/${file2} || ! -e ${ROOT3}/${file3}) then
    echo 'ERROR! File(s) were not found in the directory. The script cannot continue.'
    echo 'Please check the config file.'
    echo 'Directories:'
    echo $ROOT1
    echo $ROOT2
    echo $ROOT3
    rm list.txt
    rm filelist.txt
#   rm -r ${start}_$title
    rm -r logfiles
    rm -r maps
    rm -r dsets
    rm -r graphs
    exit 1
  endif

  ./grib2ctl -verf $ROOT1/$file1 ./${title1}_${file1}.idx >> ${title1}_${file1}.ctl
  gribmap -v -i ${title1}_${file1}.ctl >> log_${file1}_${title1}_gribmap.txt

  ./grib2ctl -verf $ROOT2/$file2 ./${title2}_${file2}.idx >> ${title2}_${file2}.ctl
  gribmap -v -i ${title2}_${file2}.ctl >> log_${file2}_${title2}.ctl_gribmap.txt

  ./grib2ctl -verf $ROOT3/$file3 ./${title3}_${file3}.idx >> ${title3}_${file3}.ctl
  gribmap -v -i ${title3}_${file3}.ctl >> log_${file3}_${title3}.ctl_gribmap.txt

  ./grib2ctl -verf $ROOT_NR/$file4 ./$file4.idx >> $file4.ctl
  gribmap -v -i $file4.ctl >> log_${file4}_gribmap.txt

  if($step != 0) then
    @ chr=$chr + $step
  endif
end

if($step == 0) then
  set chr=$fhr
else
  set chr=0
endif

# Create Datasets and Graphs.

if($step != 0) then

  set chr=0
  echo 'Creating datasets...'

  foreach line ("`cat filelist.txt`")

    echo 'Creating datasets for FHR '$chr'...'

    set file1=`echo $line | cut -d " " -f1`
    set file2=`echo $line | cut -d " " -f2`
    set file3=`echo $line | cut -d " " -f3`
    set file4=`echo $line | cut -d " " -f4`

    /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -bpcx "run FindLatLon.gs $file1 $file2" >> log_LatLon_dsets.txt
    /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -bpcx "run AVG_RMS_triple.gs $file1 $file2 $file3 $file4 $start $chr" >> log_AVG_RMS.txt

    @ chr=$chr + $step
  end

  echo 'Creating Graphs...'

    /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -blcx "run MSLP_error_triple.gs $title1 $title2 $title3 $titlenr $start $step $fhr"
endif

# Cleanup.

echo 'Cleaning up...'
mv log_* logfiles/

mv 3plot_wind*_nr.png maps/3plotWinds/NatureRun
mv 3plot_wind*.png maps/3plotWinds
mv *_nr.png maps/NatureRun/
mv mplot_*.png maps/
mv *$start*.txt dsets/
mv *_graph.png graphs/

#mv logfiles ${start}_$title
#mv maps ${start}_$title
#mv dsets ${start}_$title
#mv graphs ${start}_$title

rm *.idx
rm *.ctl

rm list.txt
rm filelist.txt
