#!/bin/csh 

# WRFout processor script
# Created by: Bryan M. Williams on August 26, 2013

if($#argv == 3) then
   set start=$1
   set fhr=$2
   set step=$3
   set chr=0
endif

if($#argv == 4) then
  set start=$1
  set chr=$2
  set fhr=$3
  set step=$4
endif

  if($chr > $fhr) then
    echo "Error: Starting hour is greater than ending hour."
    exit 2
  endif

  if($fhr < $step) then
    echo "Error: Time increment greater than forecast hour."
    exit 3
  endif

# Set current directory, load config file, and ask user to cancel if there's any mistake.

  set dir=`pwd`
  source $dir/config

  clear

  echo "GRAPHICS GENERATOR SETTINGS..."
  echo "------------------------------"
  echo "Forecast Date: "$start
  echo " "
  echo "Starting Hour: "$chr
  echo "Ending Hour:   "$fhr

  if($step == 0) then
    echo " "
    echo "A single analysis will be done at the starting hour."
  else
    echo " "
    echo "Time increment (hours): "$step
  endif

  echo " "
  echo "Title: "$title
  echo " "

if($run_single == 1) then
  echo "Path to files is: "$SIN_ROOT
  echo "Path to nature run is: "$ROOT_NR
  echo "File to run is: "$SIN_TYPE
else
  echo "Path to files is: "$ROOT1
  echo "Path to nature run is: "$ROOT_NR
endif
 
# echo " "
# echo "Please double check these settings."
# echo " "
# echo "PRESS CTRL+C TO ABORT WITHIN THE NEXT 10 SECONDS IF THERE IS ANY ERROR..."
  sleep 3

  clear

  echo "Starting process..."

if($step == 0) then
  set chr=$fhr
else
  if($#argv == 4) then
    set chr=$2
  else
    set chr=0
  endif
endif

set date=`date +'%Y%m%d%H%M'`
set timestring=`date`

# If indicated in the config, delete the maps and logfiles folder.

  mkdir ${start}_$title

  mkdir logfiles
  mkdir maps
  mkdir maps/NatureRun
  mkdir maps/3plotWinds
  mkdir maps/3plotWinds/NatureRun
  mkdir dsets
  mkdir graphs/

  set init_ctl=1
  set isfirstdate=1
# echo $isfirstdate

# Create file lists.

#echo 'Creating lists...'

echo -n 'Creating files.'

while($fhr >= $chr && $run_single != 1)
  if(`echo $chr | wc -c` - 1 == 1) then
    set fname=${ROOT_TYPE}'00'${chr}${ROOT_END}
  else if(`echo $chr | wc -c` - 1 == 2) then
    set fname=${ROOT_TYPE}'0'${chr}${ROOT_END}
  else
    set fname=${ROOT_TYPE}${chr}${ROOT_END}
  endif
  set cdate=`./timestring.sh $start $chr`
  if($isfirstdate == 1) then
#   echo 'Setting first date...'
    set firstdate=$cdate
#   echo $firstdate
    set isfirstdate=0
  endif
  set nrname=${NR_type}${cdate}'00'
  echo $fname' '$nrname >> list.txt
  echo $fname'.ctl '$nrname'.ctl' >> filelist.txt
  if($step == 0) then
    break
  else
    @ chr=$chr + $step
  endif
end

echo -n '.'

if($run_single == 1) then
  set cdate=`./timestring.sh $start $chr`
  if($isfirstdate == 1) then
#   echo 'Setting first date...'
    set firstdate=$cdate
#   echo $firstdate
  endif
  set nrname=${NR_type}${cdate}'00'
  echo $SIN_TYPE' '$nrname >> list.txt
  echo $SIN_TYPE'.ctl '$nrname'.ctl' >> filelist.txt
endif

echo -n '.'

# If the required directories are missing, create them.

if(! -d logfiles) then
  echo 'WARNING: Logfiles directory missing! creating new directory...'
  mkdir logfiles
endif

if(! -d maps) then
  echo 'WARNING: Maps directory missing! Creating new directory...'
  mkdir maps
endif

# Create the control and index files to be used in the script.

if($step == 0) then
  set chr=$fhr
else
  if($#argv == 4) then
    set chr=$2
  else
    set chr=0
  endif
endif

#echo -n 'Creating control and index files.'

foreach line ("`cat list.txt`")
  set file1=`echo $line | cut -d " " -f1`
  set file2=`echo $line | cut -d " " -f2`
  
  if(! -e ${ROOT1}/${file1}) then
    echo " "
    echo 'FATAL ERROR! "'$file1'" was not found in the directory. The script cannot continue.'
    echo 'The directory is: '${ROOT1}
    echo 'Please check the config file.'
    echo 'Removing folders...'
    rm list.txt
    rm filelist.txt
    rm -r ${start}_$title
    rm -r logfiles
    rm -r maps
    rm -r dsets
    rm -r graphs
    echo 'Exiting now.'
    exit 1
  endif

# echo 'grib experiment'

  ./grib2ctl -verf $ROOT1/$file1 ./$file1.idx >> $file1.ctl
  gribmap -v -i $file1.ctl >> log_${file1}_gribmap.txt


# echo 'grib nr'

  ./grib2ctl -verf $ROOT_NR/$file2 ./$file2.idx >> $file2.ctl
  gribmap -v -i $file2.ctl >> log_${file2}_gribmap.txt

# echo 'before if statement'
# echo $firstdate

  if($init_ctl == 1 && $chr != 0) then
#   echo 'inside if statement'
#   echo "Found first date."
    set titleprev=`echo ${file1}'.ctl'`
#   echo $titleprev
    set nrprevdate=`./timestring.sh $firstdate -$step` 
#   echo $nrprevdate
    set nrprev=${NR_type}${nrprevdate}'00'
    set titlenrprev=`echo ${nrprev}`

    ./grib2ctl -verf $ROOT_NR/$titlenrprev ./$titlenrprev.idx >> $titlenrprev.ctl
    gribmap -v -i $titlenrprev.ctl >> log_${titlenrprev}_gribmap.txt

    set titlenrprev=`echo ${nrprev}'.ctl'`
    set init_ctl=0
  endif

  if($step != 0) then
    @ chr=$chr + $step
    echo -n '.'
  endif
end

echo 'done.'

if($step == 0) then
  set chr=$fhr
else
  if($#argv == 4) then
    set chr=$2
  else
    set chr=0
  endif
endif

# Create graphics.

if($run_single == 1) then
  echo 'WARNING: Single analysis switch is set to 1. Unusual results may occur if more than one hour is requested.'
endif

set completed=0

if($chr != 0) then
  set total=`echo "$fhr/$step" | bc`
else
  set total=`echo "($fhr/$step)" + 1 | bc`
endif

echo 'Creating maps.'
foreach line ("`cat filelist.txt`")

  set file1=`echo $line | cut -d " " -f1`
  set file2=`echo $line | cut -d " " -f2`

# echo 'Creating maps for FHR '$chr'...'

  set percent=`echo "scale=2; $completed*100/$total" | bc`

  @ completed=$completed + 1

  echo "FHR "$chr"... ("$completed"/"$total") ["$percent"%]"
 
  set cdate=`./timestring.sh $start $chr`

#  echo $titleprev' '$titlenrprev

#  echo $file1' '$titleprev
#  echo $file2' '$titlenrprev

  /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -bpcx "run FindLatLon.gs $file1 $file2" >> log_LatLon.txt
  /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -bpcx "run mplot_test.gs $file1 $start $chr $title $run_single $titleprev $titlenrprev" >> log_mplot.txt
  /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -bpcx "run mplot_test_nr.gs $file2 $start $cdate $chr $titlenr $run_single $titleprev $titlenrprev" >> log_mplot_nr.txt
  /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -bpcx "run 3plot_wind.gs $file1 $start $chr $title $run_single $level1 $level2 $level3 0" >> log_3plot_wind.txt
  /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -bpcx "run 3plot_wind.gs $file2 $cdate $chr $titlenr $run_single $level1 $level2 $level3 1" >> log_3plot_wind_nr.txt

  if($chr <= $fhr && $chr != 0) then
    set titleprev=$file1
  endif

  if($firstdate != 2005080100) then
    set titlenrprev=$file2
  endif

  if($step != 0) then
    @ chr=$chr + $step
  endif

end

echo "Maps finished."

# Create Datasets and Graphs.

if($step != 0) then

  if($#argv == 4) then
    set chr=$2
  else
    set chr=0
  endif

  set completed=0

  if($chr != 0) then
    set total=`echo "$fhr/$step" | bc`
  else
    set total=`echo "($fhr/$step)" + 1 | bc`
  endif

  echo 'Creating datasets.'

  foreach line ("`cat filelist.txt`")

#   echo 'Creating datasets for FHR '$chr'...'

    set percent=`echo "scale=2; $completed*100/$total" | bc`

    @ completed=$completed + 1

    echo "FHR "$chr"... ("$completed"/"$total") ["$percent"%]"

    set file1=`echo $line | cut -d " " -f1`
    set file2=`echo $line | cut -d " " -f2`
  
    /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -bpcx "run FindLatLon.gs $file1 $file2" >> log_LatLon_dsets.txt
    /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -bpcx "run AVG_RMS.gs $file1 $file2 $start $chr $level1 $level2 $level3" >> log_AVG_RMS.txt

    @ chr=$chr + $step
  end

    
    echo "Datasets finished."

    if($run_single == 1) then
      echo 'Graphs will not be created because the single run switch is set to 1.'
    else
      echo -n 'Creating Graphs...' 
     
      if($#argv == 4) then
        set chr=$2
      else
        set chr=0
      endif

      /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -blcx "run graph_mplot.gs $title $titlenr $start $chr $step $fhr $level1 $level2 $level3" >> log_graphs.txt

      /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -blcx "run wind10m_error.gs $title $titlenr $start $step $fhr" >> log_wind10m_error.txt
      /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -blcx "run wind_error_multi.gs $title $titlenr $start $step $fhr $level1 $level2 $level3" >> log_wind_error_multi.txt
      /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -blcx "run uwind10m_error.gs $title $titlenr $start $step $fhr" >> log_uwind10m_error.txt
      /misc/whome/Lisa.R.Bucci/grads-2.0.1.oga.1/Contents/grads -blcx "run vwind10m_error.gs $title $titlenr $start $step $fhr" >> log_vwind10m_error.txt

      echo "Graphs finished."
    endif
endif

# Cleanup.

echo 'Cleaning up...'
mv log_* logfiles/

mv 3plot_wind*_nr.png maps/3plotWinds/NatureRun
mv 3plot_wind*.png maps/3plotWinds
mv *_nr.png maps/NatureRun/
mv mplot_*.png maps/
mv *$start*.txt dsets/
mv *_graph.png graphs/

mv logfiles ${start}_$title
mv maps ${start}_$title
mv dsets ${start}_$title
mv graphs ${start}_$title

rm list.txt
rm filelist.txt
rm *.ctl
rm *.idx

if( -e LatLon) then
  rm LatLon
endif

if($zip_folder == 1) then
  echo 'Zipping image directory...'

  if($run_single == 1) then
    tar -zcvf ${start}_${title}_${SIN_TYPE}_${date}.tar.gz $dir/${start}_${title} >> ${start}_${title}_zipped_files.txt
    rm -r ${start}_${title}/
    mkdir ${start}_${title}_${SIN_TYPE}_${date}
    mv ${start}_${title}_${SIN_TYPE}_${date}.tar.gz ${start}_${title}_${SIN_TYPE}_${date}
    mv -r ${start}_${title}_zipped_files.txt ${start}_${title}_${SIN_TYPE}_${date}
  else
    tar -zcvf ${start}_${title}_${date}.tar.gz $dir/${start}_${title} >> ${start}_${title}_zipped_files.txt
    rm -r ${start}_${title}/
    mkdir ${start}_${title}_${date}
    mv ${start}_${title}_${date}.tar.gz ${start}_${title}_${date}
    mv ${start}_${title}_zipped_files.txt ${start}_${title}_${date}
  endif
else
  echo 'The folder will not be zipped as per the config file.'
endif

echo 'The script finished sucessfully. Exiting now.'
exit 0
